@@ -20,6 +20,3 @@ def pprint() -> None:
           f'{Fore.GREEN}load_ram{Style.RESET_ALL}: {get_ram_load()}%'
     )
 
-#if __name__ == '__main__':
-
-pprint()
